Table of contents
-----------------

* [Introduction](#introduction)
* [Features](#features)
* [Installation](#installation)
* [Sub-modules](#sub-modules)
* [FAQ](#faq)
* [Notes](#notes)
* [Known Issues](#known-issues)


Introduction
------------

The **Schema.org Blueprints Demo** module provides an opinionated demo of
Schema.org Blueprints built on top of Drupal’s standard profile with default
content and translations.

This module provides a composer.libraries.json file that allows sites to
download and install contributed modules with patches which are used to set up
a full demo of the Schema.org Blueprints module within a progressively decoupled
Drupal instance.

**THIS MODULE SHOULD ONLY BE INSTALLED ON A PLAIN VANILLA STANDARD
INSTANCE OF DRUPAL**


Features
--------

**Administration**

A radically new administration interface using the Gin admin theme

- Modern administrative theme
- Dedicated and branded login page
- Customizable administrative toolbar
- Customizable administrative dashboards

**Content authoring**

Examples of Drupal's content authoring best practices and patterns

- Media support
- Media library
- Paragraph library
- Embedded content
- Content browsing
- Inline entity forms
- Automatic entity labels
- Content cloning
- Drag-n-drop file uploads
- Link management
- PDF generation
- URL generation
- Decoupling using Next.js

**Multilingual support**

- Language switching

**Default content**

- Example recipes in English and Spanish copied from the
  [Umami demo install profile](https://www.drupal.org/docs/umami-drupal-demonstration-installation-profile).


Installation
------------

**IMPORTANT: The Schema.org Blueprints Demo required Drupal 10.1.x**

- [Use Composer to install Drupal and manage dependencies](https://www.drupal.org/docs/develop/using-composer/manage-dependencies).
- Add the Schema.org Blueprints Demo’s composer.libraries.json files to composer.json.
  - Update the root `composer.json` file to include `chosen/composer.libraries.json`, 
    `dropzonejs/composer.libraries.json`, 
    and `schemadotorg/composer.libraries.json`.
- Install the [Schema.org Blueprints Demo](https://www.drupal.org/project/schemadotorg_demo/releases/1.0.x-dev) module via Composer.
  - Set install path for schemadotorg_demo. See example below.
  - Run `composer require 'drupal/schemadotorg_demo-schemadotorg_demo:1.0.x-dev@dev' -W`. 
  - Repeat until there are no more changes.
- Install the Schema.org Blueprints Demo.
  - **OPTION 1**
    - Install plain vanilla standard instance of Drupal.
      - Run `drush site-install`.
    - Install the Schema.org Blueprints Demo.
      - Run `drush en schemadotorg_demo`.
  - **OPTION 2**
    - Install [Schema.org Blueprint Demo profile](https://www.drupal.org/sandbox/jrockowitz/3355842).
      - Run `drush site-install schemadotorg_demo_profile`.
    - Install the Schema.org Blueprints Demo.
      - Run `drush en schemadotorg_demo`.
  - **OPTIONS 3**
    - From the project root run one of the below install scripts.
      - `web/modules/contrib/schemadotorg_demo/scripts/schemadotorg_demo.sh install_demo_standard`
      - `web/modules/contrib/schemadotorg_demo/scripts/schemadotorg_demo.sh install_demo_admin`
      - `web/modules/contrib/schemadotorg_demo/scripts/schemadotorg_demo.sh install_demo_next`
      - `web/modules/contrib/schemadotorg_demo/scripts/schemadotorg_demo.sh install_demo_translation`


Below is an example of what must be added to your projects composer.json file to include Schema.org Blueprints Demo. Adjust it to match the location of your contrib modules directory.

```
{
    "require": {
        ...    
        "schemadotorg_demo/schemadotorg_demo/": "1.0.x-dev@dev"
    },
    "require-dev": {
        ...
        "cweagans/composer-patches": "*",
        "wikimedia/composer-merge-plugin": "*",
    },
    "config": {
        "allow-plugins": {
            ...
            "cweagans/composer-patches": true,
            "wikimedia/composer-merge-plugin": true
        },
    },
    "extra": {
        "installer-paths": {
          ...
          "web/modules/contrib/schemadotorg_demo": ["drupal/schemadotorg_demo-schemadotorg_demo"],
        },
        "merge-plugin": {
            "include": [
                "web/modules/contrib/chosen/composer.libraries.json",
                "web/modules/contrib/dropzonejs/composer.libraries.json",
                "web/modules/contrib/schemadotorg/composer.libraries.json",
                "web/modules/contrib/schemadotorg_demo/composer.libraries.json"
            ],
            "merge-extra": true,
            "merge-extra-deep": true
        }
    }
}
```


Sub-modules
-----------

Below are sub-modules which enable different functionality and feature sets.

- **[Schema.org Blueprints Demo Standard](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_standard)**  
  Provides an opinionated demo of Schema.org Blueprints built on top of Drupal's standard profile.

- **[Schema.org Blueprints Demo Admin](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_admin)**  
  Provides admin UI enhancements for Schema.org Blueprints demo.

- **[Schema.org Blueprints Demo Next.js](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_next)**  
  Provides a demo Schema.org Blueprints using Next.js for Drupal.

- **[Schema.org Blueprints Demo Translation](https://git.drupalcode.org/project/schemadotorg_demo/-/tree/1.0.x/modules/schemadotorg_demo_translation)**  
  Provides translation support for the Schema.org Blueprints demo.

  
FAQ
---

**Why does this module only contain a composer.libraries.json file and \*.info.yml file?**

The composer.libraries.json file provides a quick way to include or cut-n-paste
the demo's dependencies. The \*.info.yml file provides a single module that is
used to enable the installation of a complete demo while allowing individual
parts of the demo to be maintained as smaller modules.


Notes
-----

The below patch breaks the Next.js module's JSON:API support.
```
    "patches": {
      "drupal/core": {
        "Issue #3100732: Allow specifying `meta` data on JSON:API objects": "https://www.drupal.org/files/issues/2022-05-15/3100732-33.patch"
      },
    }
```


Known Issues
------------

- [Issue #3316265: Field description is not displayed for text format (i.e. body)](https://www.drupal.org/project/gin/issues/3316265)
