#!/bin/bash

function function_exists() {
  type "$1" &>/dev/null && return 0 || return 1
}

function help() {
  echo "schemadotorg_demo.sh";
  echo;
  echo "Installs a demo of the Schema.org Blueprints module.";
  echo;
  echo "This scripts assumes you are starting with a plain vanilla standard instance of Drupal.";
  echo;
  echo "The below commands should be executed from the root of your Drupal installation.";
  echo;
  echo "Usage:"
  echo;
  IFS=$'\n'
  for f in $(declare -F); do
    function_name=${f:11}
    if [[ ! $function_name =~ ^(help|function_exists)$ ]]; then
      echo "./schemadotorg_demo.sh $function_name";
    fi
  done
}

function install() {
  local profile=${1:-"schemadotorg_demo_profile"};
  local email=`git config user.email`;

  echo "Installing $profile profile";
  drush -yv site-install --account-mail="$email"\
    --account-name=${SCHEMADOTORG_ACCOUNT_NAME:-''}\
    --account-pass=${SCHEMADOTORG_ACCOUNT_PASS:-''}\
    --site-mail="$email"\
    --site-name="Schema.org Blueprints Demo"\
    $profile;

  drush -y config-set system.site slogan 'A demo of the Schema.org Blueprints module for Drupal.';
}

################################################################################

function install_demo_standard() {
  install;
  drush -y pm:enable schemadotorg_demo_standard;
}

function install_demo_admin() {
  install;
  drush -y pm:enable schemadotorg_demo_standard;
  drush -y pm:enable schemadotorg_demo_admin;
}

function install_demo_next() {
  install_demo_admin;
  drush -y pm:enable schemadotorg_demo_next;
}

function install_demo_translation() {
  install_demo_admin;
  drush -y pm:enable schemadotorg_demo_translation;
}

################################################################################

function_name=$1; shift;

if function_exists $function_name; then

  $function_name $@;

else

  if [[ ! -z "$function_name" ]]; then
    echo "Function to '$function_name' does not exist.";
    echo;
  fi

  help;

fi
